#
# spec file for package cmake-fedora
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cmake-fedora
Version:        2.9.3
Release:        bp153.1.14
Summary:        CMake modules and scripts
License:        BSD-3-Clause
URL:            https://pagure.io/cmake-fedora
Source0:        https://pagure.io/cmake-fedora/archive/%{version}/cmake-fedora-%{version}.tar.gz
BuildRequires:  cmake >= 2.6.2
Recommends:     %{name}-modules = %{version}-%{release}
BuildArch:      noarch

%description
cmake-fedora consists a set of scripts and cmake modules that simply the
release process of a *nix software package,  especially for
Fedora and EPEL.

%package modules
Summary:        CMake modules
Requires:       cmake >= 2.6.2

%description modules
cmake-fedora consists a set of scripts and cmake modules that simply the
release process of a *nix software package,  especially for
Fedora and EPEL.

%prep
%autosetup

%build
touch .gitignore
%cmake \
  -DCMAKE_FEDORA_ENABLE_FEDORA_BUILD=0 \
  -Wno-dev
%cmake_build

%install
%cmake_install

rm -rf %{buildroot}%{_datadir}/doc/

%files
%doc AUTHORS ChangeLog README.md RELEASE-NOTES.txt TODO.md
%license COPYING
%config %{_sysconfdir}/cmake-fedora.conf
%{_bindir}/cmake-fedora-fedpkg
%{_bindir}/cmake-fedora-koji
%{_bindir}/cmake-fedora-newprj
%{_bindir}/cmake-fedora-pkgdb
%{_bindir}/cmake-fedora-zanata
%{_bindir}/cmake-fedora-reset
%{_bindir}/koji-build-scratch
%{_datadir}/cmake/Templates/fedora

%files modules
%{_datadir}/cmake/Modules/CmakeFedoraScript.cmake
%{_datadir}/cmake/Modules/DateTimeFormat.cmake
%{_datadir}/cmake/Modules/ManageAPIDoc.cmake
%{_datadir}/cmake/Modules/ManageArchive.cmake
%{_datadir}/cmake/Modules/ManageChangeLogScript.cmake
%{_datadir}/cmake/Modules/ManageDependency.cmake
%{_datadir}/cmake/Modules/ManageEnvironment.cmake
%{_datadir}/cmake/Modules/ManageEnvironmentCommon.cmake
%{_datadir}/cmake/Modules/ManageFile.cmake
%{_datadir}/cmake/Modules/ManageGConf.cmake
%{_datadir}/cmake/Modules/ManageGettextScript.cmake
%{_datadir}/cmake/Modules/ManageGitScript.cmake
%{_datadir}/cmake/Modules/ManageMessage.cmake
%{_datadir}/cmake/Modules/ManageRPM.cmake
%{_datadir}/cmake/Modules/ManageRPMScript.cmake
%{_datadir}/cmake/Modules/ManageRelease.cmake
%{_datadir}/cmake/Modules/ManageReleaseFedora.cmake
%{_datadir}/cmake/Modules/ManageSourceVersionControl.cmake
%{_datadir}/cmake/Modules/ManageString.cmake
%{_datadir}/cmake/Modules/ManageTarget.cmake
%{_datadir}/cmake/Modules/ManageTranslation.cmake
%{_datadir}/cmake/Modules/ManageUninstall.cmake
%{_datadir}/cmake/Modules/ManageUpload.cmake
%{_datadir}/cmake/Modules/ManageVariable.cmake
%{_datadir}/cmake/Modules/ManageVersion.cmake
%{_datadir}/cmake/Modules/ManageZanata.cmake
%{_datadir}/cmake/Modules/ManageZanataDefinition.cmake
%{_datadir}/cmake/Modules/ManageZanataScript.cmake
%{_datadir}/cmake/Modules/ManageZanataSuggest.cmake
%{_datadir}/cmake/Modules/cmake_uninstall.cmake.in

%changelog
* Tue May  5 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.9.3:
  * Fixed cmake-fedora-fedpkg failed to push to bodhi.
  * Target tag_pre now depends on target module-only.
* Thu Nov  7 2019 Martin Pluskal <mpluskal@suse.com>
- Use more of modern cmake macros
* Thu Nov  7 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 2.9.2
  * Fixed RHBZ#1476070 - cmake-fedora-fedpkg failed to handle multiple builds
  * Fixed the cmake-fedora-fedpkg related path SRPM bug
  * Fixed RHBZ#1475682 - ChangeLog failed to update after doing the git reset
  - -hard HEAD
  * Fixed RHBZ#1474591 - Adopt bodhi version 2
  * Fixed RHBZ#1474624 - Bodhi UpdateType is mistakenly set as newpackage
  * cmake-fedora-pkgdb new sub-commands:
    + git-branch package: List the git-branches of package
    + newest-nvr: Return NVR of master branch
    + newest-changelog: Return the latest ChangeLog in master branch.
  * koji-build-scratch is now back to use koji build --scratch
  * MANAGE_UPLOAD_FEDORAHOSTED is marked as depreciated
    But MANAGE_UPLOAD_PAGURE is not implemented yet, as pagure does not
    support scp upload yet
  * Fixed RHBZ#1424757 - cmake-fedora: failed to handle f26-pending
  * Fixed RHBZ#1425263 - cmake-fedora: migrate from fedorahosted to pagure
  * Fixed fedpkg --dist depreciate warning
  * cmake-fedora-fedpkg: fix when git change is at staging, but not committed
    yet.
  * cmake-fedora-reset: The program that clean and reset the build environment
  * Fixed Bug 1367656 - cmake-fedora-fedpkg: failed when commit is clean
* Sun May 22 2016 mpluskal@suse.com
- Small spec file cleanup
* Sun May 22 2016 hillwood@opensuse.org
- Initial package for version 2.6.0
